@@ -27,7 +27,7 @@ class TestOverwrites(unittest.TestCase):
             [
                 sys.executable, 'yt_dlp/__main__.py',
                 '-o', 'test.webm',
-                'https://www.youtube.com/watch?v=jNQXAC9IVRw'
+                'https://www.youtube.com/watch?v=jNQXAC9IVRw',
             ], cwd=root_dir, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         sout, serr = outp.communicate()
         self.assertTrue(b'has already been downloaded' in sout)
@@ -39,7 +39,7 @@ class TestOverwrites(unittest.TestCase):
             [
                 sys.executable, 'yt_dlp/__main__.py', '--yes-overwrites',
                 '-o', 'test.webm',
-                'https://www.youtube.com/watch?v=jNQXAC9IVRw'
+                'https://www.youtube.com/watch?v=jNQXAC9IVRw',
             ], cwd=root_dir, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         sout, serr = outp.communicate()
         self.assertTrue(b'has already been downloaded' not in sout)
