@@ -1,13 +1,15 @@
 import base64
 import os.path
 import re
+import urllib.parse
 
 from .common import InfoExtractor
-from ..compat import compat_urllib_parse_unquote
 from ..utils import (
     ExtractorError,
+    update_url,
     update_url_query,
     url_basename,
+    urlencode_postdata,
 )
 
 
@@ -19,8 +21,8 @@ class DropboxIE(InfoExtractor):
             'info_dict': {
                 'id': 'nelirfsxnmcfbfh',
                 'ext': 'mp4',
-                'title': 'youtube-dl test video \'ä"BaW_jenozKc'
-            }
+                'title': 'youtube-dl test video \'ä"BaW_jenozKc',
+            },
         }, {
             'url': 'https://www.dropbox.com/s/nelirfsxnmcfbfh',
             'only_matching': True,
@@ -36,43 +38,56 @@ class DropboxIE(InfoExtractor):
         },
     ]
 
+    def _yield_decoded_parts(self, webpage):
+        for encoded in reversed(re.findall(r'registerStreamedPrefetch\s*\(\s*"[\w/+=]+"\s*,\s*"([\w/+=]+)"', webpage)):
+            yield base64.b64decode(encoded).decode('utf-8', 'ignore')
+
     def _real_extract(self, url):
         mobj = self._match_valid_url(url)
         video_id = mobj.group('id')
         webpage = self._download_webpage(url, video_id)
-        fn = compat_urllib_parse_unquote(url_basename(url))
+        fn = urllib.parse.unquote(url_basename(url))
         title = os.path.splitext(fn)[0]
+        content_id = None
 
-        password = self.get_param('videopassword')
-        if (self._og_search_title(webpage) == 'Dropbox - Password Required'
-                or 'Enter the password for this link' in webpage):
+        for part in self._yield_decoded_parts(webpage):
+            if '/sm/password' in part:
+                content_id = self._search_regex(r'content_id=([\w.+=/-]+)', part, 'content ID')
+                break
 
-            if password:
-                content_id = self._search_regex(r'content_id=(.*?)["\']', webpage, 'content_id')
-                payload = f'is_xhr=true&t={self._get_cookies("https://www.dropbox.com").get("t").value}&content_id={content_id}&password={password}&url={url}'
-                response = self._download_json(
-                    'https://www.dropbox.com/sm/auth', video_id, 'POSTing video password', data=payload.encode('UTF-8'),
-                    headers={'content-type': 'application/x-www-form-urlencoded; charset=UTF-8'})
-
-                if response.get('status') != 'authed':
-                    raise ExtractorError('Authentication failed!', expected=True)
-                webpage = self._download_webpage(url, video_id)
-            elif self._get_cookies('https://dropbox.com').get('sm_auth'):
-                webpage = self._download_webpage(url, video_id)
-            else:
+        if content_id:
+            password = self.get_param('videopassword')
+            if not password:
                 raise ExtractorError('Password protected video, use --video-password <password>', expected=True)
 
-        formats, subtitles, has_anonymous_download = [], {}, False
-        for encoded in reversed(re.findall(r'registerStreamedPrefetch\s*\(\s*"[\w/+=]+"\s*,\s*"([\w/+=]+)"', webpage)):
-            decoded = base64.b64decode(encoded).decode('utf-8', 'ignore')
+            response = self._download_json(
+                'https://www.dropbox.com/sm/auth', video_id, 'POSTing video password',
+                data=urlencode_postdata({
+                    'is_xhr': 'true',
+                    't': self._get_cookies('https://www.dropbox.com')['t'].value,
+                    'content_id': content_id,
+                    'password': password,
+                    'url': update_url(url, scheme='', netloc=''),
+                }))
+            if response.get('status') != 'authed':
+                raise ExtractorError('Invalid password', expected=True)
+
+            webpage = self._download_webpage(url, video_id)
+
+        formats, subtitles = [], {}
+        has_anonymous_download = False
+        thumbnail = None
+        for part in self._yield_decoded_parts(webpage):
             if not has_anonymous_download:
                 has_anonymous_download = self._search_regex(
-                    r'(anonymous:\tanonymous)', decoded, 'anonymous', default=False)
+                    r'(anonymous:\tanonymous)', part, 'anonymous', default=False)
             transcode_url = self._search_regex(
-                r'\n.(https://[^\x03\x08\x12\n]+\.m3u8)', decoded, 'transcode url', default=None)
+                r'\n.?(https://[^\x03\x08\x12\n]+\.m3u8)', part, 'transcode url', default=None)
             if not transcode_url:
                 continue
             formats, subtitles = self._extract_m3u8_formats_and_subtitles(transcode_url, video_id, 'mp4')
+            thumbnail = self._search_regex(
+                r'(https://www\.dropbox\.com/temp_thumb_from_token/[\w/?&=]+)', part, 'thumbnail', default=None)
             break
 
         # downloads enabled we can get the original file
@@ -81,12 +96,13 @@ class DropboxIE(InfoExtractor):
                 'url': update_url_query(url, {'dl': '1'}),
                 'format_id': 'original',
                 'format_note': 'Original',
-                'quality': 1
+                'quality': 1,
             })
 
         return {
             'id': video_id,
             'title': title,
             'formats': formats,
-            'subtitles': subtitles
+            'subtitles': subtitles,
+            'thumbnail': thumbnail,
         }
