@@ -1,11 +1,10 @@
 from .common import InfoExtractor
-from ..compat import compat_str
 from ..networking.exceptions import HTTPError
 from ..utils import (
+    ExtractorError,
+    int_or_none,
     qualities,
     strip_or_none,
-    int_or_none,
-    ExtractorError,
 )
 
 
@@ -35,12 +34,12 @@ class FilmOnIE(InfoExtractor):
 
         try:
             response = self._download_json(
-                'https://www.filmon.com/api/vod/movie?id=%s' % video_id,
+                f'https://www.filmon.com/api/vod/movie?id={video_id}',
                 video_id)['response']
         except ExtractorError as e:
             if isinstance(e.cause, HTTPError):
                 errmsg = self._parse_json(e.cause.response.read().decode(), video_id)['reason']
-                raise ExtractorError('%s said: %s' % (self.IE_NAME, errmsg), expected=True)
+                raise ExtractorError(f'{self.IE_NAME} said: {errmsg}', expected=True)
             raise
 
         title = response['title']
@@ -124,10 +123,10 @@ class FilmOnChannelIE(InfoExtractor):
         except ExtractorError as e:
             if isinstance(e.cause, HTTPError):
                 errmsg = self._parse_json(e.cause.response.read().decode(), channel_id)['message']
-                raise ExtractorError('%s said: %s' % (self.IE_NAME, errmsg), expected=True)
+                raise ExtractorError(f'{self.IE_NAME} said: {errmsg}', expected=True)
             raise
 
-        channel_id = compat_str(channel_data['id'])
+        channel_id = str(channel_data['id'])
         is_live = not channel_data.get('is_vod') and not channel_data.get('is_vox')
         title = channel_data['title']
 
@@ -155,7 +154,7 @@ class FilmOnChannelIE(InfoExtractor):
         for name, width, height in self._THUMBNAIL_RES:
             thumbnails.append({
                 'id': name,
-                'url': 'http://static.filmon.com/assets/channels/%s/%s.png' % (channel_id, name),
+                'url': f'http://static.filmon.com/assets/channels/{channel_id}/{name}.png',
                 'width': width,
                 'height': height,
             })
